@@ -12,11 +12,9 @@ class DoubleQLearning(TD):
 
     """
     def __init__(self, mdp_info, policy, learning_rate):
-        self.Q = EnsembleTable(2, mdp_info.size)
+        Q = EnsembleTable(2, mdp_info.size)
 
-        self._add_save_attr(Q='pickle', alpha='pickle')
-
-        super().__init__(mdp_info, policy, self.Q, learning_rate)
+        super().__init__(mdp_info, policy, Q, learning_rate)
 
         self.alpha = [deepcopy(self.alpha), deepcopy(self.alpha)]
 
